==> kst_1.0.0.orig.tar.gz: kst-1.0.0/kst/kst/ksteqdialog_i.h <==
/***************************************************************************
                       ksteqdialog_i.h  -  Part of KST
                             -------------------
    begin                :
    copyright            : (C) 2003 The University of Toronto
                           (C) 2003 C. Barth Netterfield
    email                :
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KSTEQDIALOGI_H
#define KSTEQDIALOGI_H

#include "eqdialog.h"
#include "kstequation.h"

class KstEqDialogI : public KstEqDialog {
  Q_OBJECT
  public:
    KstEqDialogI(QWidget* parent = 0, const char* name = 0,
        bool modal = FALSE, WFlags fl = 0 );
    virtual ~KstEqDialogI();

  public slots:
    void update();
    void updateWindow();

    bool new_I();
    bool edit_I();

    static KstEqDialogI *globalInstance();

  private:
    static KstEqDialogI *_inst;
    KstEquationPtr _getPtr(const QString &tagin);
    bool _checkEntries();
    bool _newDialog;
    KstEquationPtr DP;

    /***********************************/
    /** defined in dataobjectdialog.h **/
  public slots:
    void show_Edit(const QString &field);
    void show_New();
    void OK();
    void Init();
    void close();
    void reject();
    void populateFunctionList();

  private:
    void _fillFieldsForEdit();
    void _fillFieldsForNew();
};

#endif
// vim: ts=2 sw=2 et

==> kst_1.2.1.orig.tar.gz: kst-1.2.1/kst/kst/ksteqdialog_i.h <==
/***************************************************************************
                       ksteqdialog_i.h  -  Part of KST
                             -------------------
    begin                :
    copyright            : (C) 2003 The University of Toronto
                           (C) 2003 C. Barth Netterfield
    email                :
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KSTEQDIALOGI_H
#define KSTEQDIALOGI_H

#include "kstdatadialog.h"
#include "kstequation.h"
#include "kst_export.h"

class EqDialogWidget;

class KST_EXPORT KstEqDialogI : public KstDataDialog {
  Q_OBJECT
  public:
    KstEqDialogI(QWidget* parent = 0, const char* name = 0, bool modal = false, WFlags fl = 0);
    virtual ~KstEqDialogI();
    static KstEqDialogI *globalInstance();

  public slots:
    void update();
    void updateWindow();
    void populateEditMultiple();
    bool newObject();
    bool editObject();

  private:
    static QGuardedPtr<KstEqDialogI> _inst;
    bool checkEntries();
    bool _equationDirty;
    bool _xVectorsDirty;
    bool _doInterpolationDirty;

    bool editSingleObject(KstEquationPtr eqPtr);

  private slots:
    void setDoInterpolationDirty();

  protected:
    void fillFieldsForEdit();
    void fillFieldsForNew();

  private:
    static const QString& defaultTag;
    void populateFunctionList();
    EqDialogWidget *_w;
};

#endif
// vim: ts=2 sw=2 et
